@@ -1,7 +1,7 @@
 require 5.002;
 
 
-$DBD::ASAny::VERSION = '1.12';
+$DBD::ASAny::VERSION = '1.13';
 
 {
     package DBD::ASAny;
@@ -30,6 +30,10 @@ $DBD::ASAny::VERSION = '1.12';
     $errstr = "";	# holds error string for DBI::errstr (XXX SHARED!)
     $drh = undef;	# holds driver handle once initialised
 
+    sub CLONE {
+	$drh = undef;
+    }
+
     sub driver {
 	return $drh if $drh;
 	my($class, $attr) = @_;
